@@ -6,8 +6,8 @@
 #
 # See the LICENSE file in the source distribution for further information.
 
-from sos.report.plugins import Plugin, RedHatPlugin,\
-    DebianPlugin, UbuntuPlugin, CosPlugin
+from sos.report.plugins import (Plugin, RedHatPlugin, DebianPlugin,
+                                UbuntuPlugin, CosPlugin)
 
 
 class Release(Plugin, UbuntuPlugin, CosPlugin):
@@ -31,7 +31,7 @@ class Release(Plugin, UbuntuPlugin, CosPlugin):
 class DebianRelease(Release, DebianPlugin):
 
     def setup(self):
-        super(DebianRelease, self).setup()
+        super().setup()
         self.add_copy_spec('/etc/debian_version')
 
 
@@ -39,6 +39,6 @@ class RedHatRelease(Release, RedHatPlugin):
 
     def setup(self):
         self.add_file_tags({'/etc/redhat-release': 'redhat_release'})
-        super(RedHatRelease, self).setup()
+        super().setup()
 
 # vim: set et ts=4 sw=4 :
